﻿using YBEE.EQM.Core;

namespace YBEE.EQM.Application;

/// <summary>
/// 缺测替补管理服务
/// </summary>
public interface IExamAbsentReplaceService
{
    #region 批量导入
    /// <summary>
    /// 上传监测缺测替补批量导入文件
    /// </summary>
    /// <param name="filePath"></param>
    /// <param name="examPlanId"></param>
    /// <returns></returns>
    Task<UploadExamDataOutput<UploadExamAbsentReplaceOutput>> Upload(string filePath, int examPlanId);
    /// <summary>
    /// 批量导入监测缺测替补
    /// </summary>
    /// <param name="input"></param>
    /// <returns></returns>
    Task<int> Import(ImportExamAbsentReplaceInput input);
    #endregion
    #region 创建编辑
    /// <summary>
    /// 添加监测缺测替补
    /// </summary>
    /// <param name="input"></param>
    /// <returns></returns>
    Task Add(AddExamAbsentReplaceInput input);
    /// <summary>
    /// 更新监测缺测替补
    /// </summary>
    /// <param name="input"></param>
    /// <returns></returns>
    Task Update(UpdateExamAbsentReplaceInput input);
    /// <summary>
    /// 添加缺测替补佐证材料
    /// </summary>
    /// <param name="input"></param>
    /// <returns></returns>
    Task AddAttachment(AddAttachmentInput input);
    /// <summary>
    /// 删除缺测替补佐证材料
    /// </summary>
    /// <param name="input"></param>
    /// <returns></returns>
    Task DelAttachment(DeleteAttachmentInput input);
    /// <summary>
    /// 验证缺测替补佐证材料
    /// </summary>
    /// <param name="examPlanId"></param>
    /// <returns></returns>
    Task<bool> VerifyAttachment(int examPlanId);
    /// <summary>
    /// 删除监测缺测替补
    /// </summary>
    /// <param name="input"></param>
    /// <returns></returns>
    Task Del(BaseId input);
    /// <summary>
    /// 清空监测缺测替补
    /// </summary>
    /// <param name="input"></param>
    /// <returns></returns>
    Task Clear(ClearExamAbsentReplaceInput input);
    /// <summary>
    /// 导出监测缺测替补上报打印表格
    /// </summary>
    /// <param name="examPlanId"></param>
    /// <returns></returns>
    Task<byte[]> ExportPrintTable(int examPlanId);
    #endregion

    #region 查询统计
    /// <summary>
    /// 分页查询监测缺测替补列表
    /// </summary>
    /// <param name="input"></param>
    /// <returns></returns>
    Task<PageResult<ExamAbsentReplaceOutput>> QueryPageList(ExamAbsentReplacePageInput input);
    /// <summary>
    /// 获取机构班级缺测替补上报人数统计列表
    /// </summary>
    /// <param name="examPlanId"></param>
    /// <param name="sysOrgId"></param>
    /// <returns></returns>
    Task<ExamAbsentReplaceCountOutput> GetOrgGradeClassStudentCount(int examPlanId, short? sysOrgId = null);
    /// <summary>
    /// 获取状态数量
    /// </summary>
    /// <returns></returns>
    Task<List<StatusCount>> QueryStatusCount(ExamAbsentReplacePageInput input);
    #endregion
}
