﻿using YBEE.EQM.Core;

namespace YBEE.EQM.Application;

/// <summary>
/// 导入监测特殊学生输入参数
/// </summary>
public class ImportExamSpecialStudentItem
{
    /// <summary>
    /// 监测计划ID
    /// </summary>
    [Required]
    public int ExamPlanId { get; set; }
    /// <summary>
    /// 监测年级ID
    /// </summary>
    [Required]
    public int ExamGradeId { get; set; }
    /// <summary>
    /// 年级ID
    /// </summary>
    [Required]
    public short GradeId { get; set; }
    /// <summary>
    /// 班级号
    /// </summary>
    [Required]
    public short ClassNumber { get; set; }
    /// <summary>
    /// 姓名
    /// </summary>
    [Required]
    public string Name { get; set; }
    /// <summary>
    /// 证件类型
    /// </summary>
    [Required]
    public CertificateType CertificateType { get; set; }
    /// <summary>
    /// 证件号码
    /// </summary>
    public string IdNumber { get; set; } = "";
    /// <summary>
    /// 性别
    /// </summary>
    public Gender? Gender { get; set; } = Core.Gender.UNKNOWN;
    /// <summary>
    /// 学籍号
    /// </summary>
    public string StudentNumber { get; set; }
    /// <summary>
    /// 申请原因
    /// </summary>
    [Required, StringLength(2000)]
    public string ApplyReason { get; set; }
    /// <summary>
    /// 家长姓名
    /// </summary>
    [StringLength(100)]
    public string PatriarchName { get; set; }
    /// <summary>
    /// 家长电话
    /// </summary>
    [StringLength(50)]
    public string PatriarchTel { get; set; }
    /// <summary>
    /// 备注
    /// </summary>
    public string Remark { get; set; }
}

/// <summary>
/// 导入监测特殊学生输入参数
/// </summary>
public class ImportExamSpecialStudentInput
{
    /// <summary>
    /// 监测计划ID
    /// </summary>
    [Required]
    public int ExamPlanId { get; set; }
    /// <summary>
    /// 机构ID
    /// </summary>
    public short? SysOrgId { get; set; }
    /// <summary>
    /// 校区ID
    /// </summary>
    public short? SysOrgBranchId { get; set; }
    /// <summary>
    /// 导入行
    /// </summary>
    [Required]
    public List<ImportExamSpecialStudentItem> Items { get; set; }
    /// <summary>
    /// 数据导入模式
    /// </summary>
    [Required]
    public DataImportMode DataImportMode { get; set; }
}

/// <summary>
/// 添加监测特殊学生上报输入参数
/// </summary>
public class AddExamSpecialStudentInput
{
    /// <summary>
    /// 监测计划ID
    /// </summary>
    [Required]
    public int ExamPlanId { get; set; }
    /// <summary>
    /// 机构ID
    /// </summary>
    [Required]
    public short SysOrgId { get; set; }
    /// <summary>
    /// 校区ID
    /// </summary>
    public short? SysOrgBranchId { get; set; }
    /// <summary>
    /// 监测年级ID
    /// </summary>
    [Required]
    public int ExamGradeId { get; set; }
    /// <summary>
    /// 年级ID
    /// </summary>
    [Required]
    public short GradeId { get; set; }
    /// <summary>
    /// 班号
    /// </summary>
    [Required]
    public short ClassNumber { get; set; }
    /// <summary>
    /// 学籍号
    /// </summary>
    [StringLength(100)]
    public string StudentNumber { get; set; } = "";

    /// <summary>
    /// 姓名
    /// </summary>
    [Required, StringLength(100)]
    public string Name { get; set; }
    /// <summary>
    /// 证件类型
    /// </summary>
    [Required]
    public CertificateType CertificateType { get; set; } = CertificateType.NONE;
    /// <summary>
    /// 证件号码
    /// </summary>
    [StringLength(50)]
    public string IdNumber { get; set; } = "";
    /// <summary>
    /// 出生日期
    /// </summary>
    public DateTime? BirthDate { get; set; }
    /// <summary>
    /// 性别
    /// </summary>
    [Required]
    public Gender Gender { get; set; } = Gender.UNKNOWN;

    /// <summary>
    /// 申请原因
    /// </summary>
    [Required, StringLength(2000)]
    public string ApplyReason { get; set; }
    /// <summary>
    /// 家长姓名
    /// </summary>
    [StringLength(100)]
    public string PatriarchName { get; set; }
    /// <summary>
    /// 家长电话
    /// </summary>
    [StringLength(50)]
    public string PatriarchTel { get; set; }

    /// <summary>
    /// 备注
    /// </summary>
    [StringLength(200)]
    public string Remark { get; set; }
}
/// <summary>
/// 更新监测特殊学生上报输入参数
/// </summary>
public class UpdateExamSpecialStudentInput
{
    /// <summary>
    /// 主键
    /// </summary>
    [Required]
    public int Id { get; set; }

    /// <summary>
    /// 校区ID
    /// </summary>
    public short? SysOrgBranchId { get; set; }

    /// <summary>
    /// 班号
    /// </summary>
    [Required]
    public short ClassNumber { get; set; }
    /// <summary>
    /// 学籍号
    /// </summary>
    [StringLength(100)]
    public string StudentNumber { get; set; } = "";

    /// <summary>
    /// 姓名
    /// </summary>
    [Required, StringLength(100)]
    public string Name { get; set; }
    /// <summary>
    /// 证件类型
    /// </summary>
    [Required]
    public CertificateType CertificateType { get; set; } = CertificateType.NONE;
    /// <summary>
    /// 证件号码
    /// </summary>
    [StringLength(50)]
    public string IdNumber { get; set; } = "";
    /// <summary>
    /// 出生日期
    /// </summary>
    public DateTime? BirthDate { get; set; }
    /// <summary>
    /// 性别
    /// </summary>
    [Required]
    public Gender Gender { get; set; } = Gender.UNKNOWN;

    /// <summary>
    /// 申请原因
    /// </summary>
    [Required, StringLength(2000)]
    public string ApplyReason { get; set; }
    /// <summary>
    /// 家长姓名
    /// </summary>
    [StringLength(100)]
    public string PatriarchName { get; set; }
    /// <summary>
    /// 家长电话
    /// </summary>
    [StringLength(50)]
    public string PatriarchTel { get; set; }

    /// <summary>
    /// 备注
    /// </summary>
    [StringLength(200)]
    public string Remark { get; set; }
}
/// <summary>
/// 清空监测特殊学生输入参数
/// </summary>
public class ClearExamSpecialStudentInput
{
    /// <summary>
    /// 监测计划ID
    /// </summary>
    [Required]
    public int ExamPlanId { get; set; }
}
/// <summary>
/// 分页查询监测特殊学生输入参数
/// </summary>
public class ExamSpecialStudentPageInput : PageInputBase
{
    /// <summary>
    /// 监测计划ID
    /// </summary>
    [Required]
    public int ExamPlanId { get; set; }
    /// <summary>
    /// 机构ID
    /// </summary>
    public short? SysOrgId { get; set; }
    /// <summary>
    /// 校区ID
    /// </summary>
    public short? SysOrgBranchId { get; set; }
    /// <summary>
    /// 年级ID
    /// </summary>
    public short? GradeId { get; set; }
    /// <summary>
    /// 班级号
    /// </summary>
    public short? ClassNumber { get; set; }
    /// <summary>
    /// 姓名
    /// </summary>
    public string Name { get; set; }
    /// <summary>
    /// 证件类型
    /// </summary>
    public CertificateType? CertificateType { get; set; }
    /// <summary>
    /// 证件号码
    /// </summary>
    [StringLength(50)]
    public string IdNumber { get; set; }
    /// <summary>
    /// 性别
    /// </summary>
    public Gender? Gender { get; set; }
    /// <summary>
    /// 学籍号
    /// </summary>
    public string StudentNumber { get; set; }
    /// <summary>
    /// 申请原因
    /// </summary>
    [StringLength(2000)]
    public string ApplyReason { get; set; }
    /// <summary>
    /// 家长电话
    /// </summary>
    [StringLength(50)]
    public string PatriarchTel { get; set; }

    /// <summary>
    /// 往期是否已认定
    /// </summary>
    public bool? IsIdentified { get; set; }

    /// <summary>
    /// 状态
    /// </summary>
    public AuditStatus? Status { get; set; }
}

/// <summary>
/// 特殊学生审核输入参数
/// </summary>
public class ExamSepcialStudentAuditInput
{
    /// <summary>
    /// 监测特殊学生ID列表
    /// </summary>
    public List<int> Ids { get; set; }
    /// <summary>
    /// 是否通过
    /// </summary>
    public bool IsApproved { get; set; }
    /// <summary>
    /// 审核意见
    /// </summary>
    public string Remark { get; set; }
}