﻿using System.ComponentModel.DataAnnotations.Schema;
using YBEE.EQM.Core;

namespace YBEE.EQM.Application;

/// <summary>
/// 批量导入监测教师
/// </summary>
public class ImportExamTeacherItem
{
    /// <summary>
    /// 监测计划ID
    /// </summary>
    [Required]
    public int ExamPlanId { get; set; }
    /// <summary>
    /// 机构ID
    /// </summary>
    public short? SysOrgId { get; set; }
    /// <summary>
    /// 姓名
    /// </summary>
    [Required]
    public string Name { get; set; }
    /// <summary>
    /// 校内职务ID
    /// </summary>
    [Required]
    public SchoolJobTitle SchoolJobTitle { get; set; } = SchoolJobTitle.TEACHER;
    /// <summary>
    /// 证件类型
    /// </summary>
    [Required]
    public CertificateType CertificateType { get; set; }
    /// <summary>
    /// 证件号码
    /// </summary>
    public string IdNumber { get; set; } = "";
    /// <summary>
    /// 性别
    /// </summary>
    public Gender? Gender { get; set; } = Core.Gender.UNKNOWN;
    /// <summary>
    /// 手机号码
    /// </summary>
    public string Mobile { get; set; } = "";
    /// <summary>
    /// 电子邮箱
    /// </summary>
    public string Email { get; set; } = "";
    /// <summary>
    /// 备注
    /// </summary>
    public string Remark { get; set; }
}

/// <summary>
/// 批量导入监测教师输入参数
/// </summary>
public class ImportExamTeacherInput
{
    /// <summary>
    /// 监测计划ID
    /// </summary>
    [Required]
    public int ExamPlanId { get; set; }
    /// <summary>
    /// 机构ID
    /// </summary>
    public short? SysOrgId { get; set; }
    /// <summary>
    /// 导入行
    /// </summary>
    [Required]
    public List<ImportExamTeacherItem> Items { get; set; }
    /// <summary>
    /// 数据导入模式
    /// </summary>
    [Required]
    public DataImportMode DataImportMode { get; set; }
}

/// <summary>
/// 添加监测教师
/// </summary>
public class AddExamTeacherInput
{
    /// <summary>
    /// 监测计划ID
    /// </summary>
    [Required]
    public int ExamPlanId { get; set; }
    /// <summary>
    /// 机构ID
    /// </summary>
    public short? SysOrgId { get; set; }

    /// <summary>
    /// 姓名
    /// </summary>
    [Required, StringLength(100)]
    public string Name { get; set; }
    /// <summary>
    /// 校内职务ID
    /// </summary>
    [Required]
    public SchoolJobTitle SchoolJobTitle { get; set; } = SchoolJobTitle.TEACHER;
    /// <summary>
    /// 证件类型
    /// </summary>
    [Required]
    public CertificateType CertificateType { get; set; } = CertificateType.NONE;
    /// <summary>
    /// 证件号码
    /// </summary>
    [StringLength(50)]
    public string IdNumber { get; set; } = "";
    /// <summary>
    /// 出生日期
    /// </summary>
    public DateTime? BirthDate { get; set; }
    /// <summary>
    /// 性别
    /// </summary>
    [Required]
    public Gender Gender { get; set; } = Gender.UNKNOWN;
    /// <summary>
    /// 手机号码
    /// </summary>
    [StringLength(50)]
    public string Mobile { get; set; } = "";
    /// <summary>
    /// 电子邮箱
    /// </summary>
    [StringLength(200)]
    public string Email { get; set; } = "";
    /// <summary>
    /// 备注
    /// </summary>
    [StringLength(200)]
    public string Remark { get; set; }
}

/// <summary>
/// 更新监测教师
/// </summary>
public class UpdateExamTeacherInput : BaseId
{
    /// <summary>
    /// 姓名
    /// </summary>
    [Required, StringLength(100)]
    public string Name { get; set; }
    /// <summary>
    /// 校内职务ID
    /// </summary>
    [Required]
    public SchoolJobTitle SchoolJobTitle { get; set; } = SchoolJobTitle.TEACHER;
    /// <summary>
    /// 证件类型
    /// </summary>
    [Required]
    public CertificateType CertificateType { get; set; } = CertificateType.NONE;
    /// <summary>
    /// 证件号码
    /// </summary>
    [StringLength(50)]
    public string IdNumber { get; set; } = "";
    /// <summary>
    /// 出生日期
    /// </summary>
    public DateTime? BirthDate { get; set; }
    /// <summary>
    /// 性别
    /// </summary>
    [Required]
    public Gender Gender { get; set; } = Gender.UNKNOWN;
    /// <summary>
    /// 手机号码
    /// </summary>
    [StringLength(50)]
    public string Mobile { get; set; } = "";
    /// <summary>
    /// 电子邮箱
    /// </summary>
    [StringLength(200)]
    public string Email { get; set; } = "";
    /// <summary>
    /// 备注
    /// </summary>
    [StringLength(200)]
    public string Remark { get; set; }
}

/// <summary>
/// 清空监测教师
/// </summary>
public class ClearExamTeacherInput
{
    /// <summary>
    /// 监测计划ID
    /// </summary>
    [Required]
    public int ExamPlanId { get; set; }
}

/// <summary>
/// 分页查询监测教师
/// </summary>
public class ExamTeacherPageInput : PageInputBase
{
    /// <summary>
    /// 监测计划ID
    /// </summary>
    [Required]
    public int ExamPlanId { get; set; }
    /// <summary>
    /// 姓名
    /// </summary>
    public string Name { get; set; }
    /// <summary>
    /// 校内职务ID
    /// </summary>
    public SchoolJobTitle? SchoolJobTitle { get; set; }
    /// <summary>
    /// 证件类型
    /// </summary>
    public CertificateType? CertificateType { get; set; }
    /// <summary>
    /// 证件号码
    /// </summary>
    public string IdNumber { get; set; }
    /// <summary>
    /// 性别
    /// </summary>
    public Gender? Gender { get; set; }
    /// <summary>
    /// 手机号码
    /// </summary>
    [StringLength(50)]
    public string Mobile { get; set; }
    /// <summary>
    /// 电子邮箱
    /// </summary>
    [StringLength(200)]
    public string Email { get; set; }
}