﻿using Furion.DatabaseAccessor;
using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata.Builders;
using System;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;

namespace YBEE.EQM.Core;

/// <summary>
/// 监测特殊学生上报信息
/// </summary>
[Comment("监测特殊学生上报信息")]
public class ExamSpecialStudent : DEntityBase, IEntityTypeBuilder<ExamSpecialStudent>
{
    /// <summary>
    /// 监测计划ID
    /// </summary>
    [Comment("监测计划ID")]
    [Required]
    public int ExamPlanId { get; set; }
    /// <summary>
    /// 机构ID
    /// </summary>
    [Comment("机构ID")]
    [Required]
    public short SysOrgId { get; set; }
    /// <summary>
    /// 校区ID
    /// </summary>
    [Comment("校区ID")]
    public short? SysOrgBranchId { get; set; }
    /// <summary>
    /// 监测年级ID
    /// </summary>
    [Comment("监测年级ID")]
    [Required]
    public int ExamGradeId { get; set; }
    /// <summary>
    /// 年级ID
    /// </summary>
    [Comment("年级ID")]
    [Required]
    public short GradeId { get; set; }
    /// <summary>
    /// 班级ID
    /// </summary>
    [Comment("班级ID")]
    [Required]
    public long SchoolClassId { get; set; }
    /// <summary>
    /// 班号
    /// </summary>
    [Comment("班号")]
    [Required]
    public short ClassNumber { get; set; }
    /// <summary>
    /// 学籍号
    /// </summary>
    [Comment("学籍号")]
    [StringLength(100)]
    public string StudentNumber { get; set; } = "";

    /// <summary>
    /// 姓名
    /// </summary>
    [Comment("姓名")]
    [Required, StringLength(100)]
    public string Name { get; set; }
    /// <summary>
    /// 证件类型
    /// </summary>
    [Comment("证件类型")]
    [Required, Column(TypeName = "smallint")]
    public CertificateType CertificateType { get; set; } = CertificateType.NONE;
    /// <summary>
    /// 证件号码
    /// </summary>
    [Comment("证件号码")]
    [StringLength(50)]
    public string IdNumber { get; set; } = "";
    /// <summary>
    /// 出生日期
    /// </summary>
    [Comment("出生日期")]
    public DateTime? BirthDate { get; set; }
    /// <summary>
    /// 性别
    /// </summary>
    [Comment("性别")]
    [Required, Column(TypeName = "smallint")]
    public Gender Gender { get; set; } = Gender.UNKNOWN;

    /// <summary>
    /// 申请原因
    /// </summary>
    [Comment("申请原因")]
    [Required, StringLength(2000)]
    public string ApplyReason { get; set; }
    /// <summary>
    /// 家长姓名
    /// </summary>
    [Comment("家长姓名")]
    [StringLength(100)]
    public string PatriarchName { get; set; }
    /// <summary>
    /// 家长电话
    /// </summary>
    [Comment("家长电话")]
    [StringLength(50)]
    public string PatriarchTel { get; set; }

    /// <summary>
    /// 备注
    /// </summary>
    [Comment("备注")]
    [StringLength(200)]
    public string Remark { get; set; }


    /// <summary>
    /// 往期是否已认定
    /// </summary>
    [Comment("往期是否已认定")]
    [Required]
    public bool IsPreIdentified { get; set; } = false;

    /// <summary>
    /// 状态
    /// </summary>
    [Comment("状态")]
    [Required, Column(TypeName = "smallint")]
    public AuditStatus Status { get; set; } = AuditStatus.AUDIT;

    /// <summary>
    /// 佐证材料
    /// [{ fileId: '123', fileName: '医院证明文件.png', fileExtName: '.png', thumbFileId: '234' }]
    /// </summary>
    [Comment("佐证材料")]
    [Column(TypeName = "json")]
    public string Attachments { get; set; } = "[]";
    /// <summary>
    /// 审核记录
    /// [{ id: 1, createTime: '2023-12-25 12:56:23', sysUserId: 5, sysUserName: '张三', sysOrgId: 5, sysOrgName: '基教科', status: 3, remark: '', actionType: 3}]
    /// </summary>
    [Comment("审核记录")]
    [Required, Column(TypeName = "json")]
    public string Audits { get; set; } = "[]";

    /// <summary>
    /// 上一期总分科目数量
    /// </summary>
    [Comment("上一期总分科目数量")]
    public short? PreTotalCourse { get; set; }
    /// <summary>
    /// 上一期总分
    /// </summary>
    [Comment("上一期总分")]
    [Column(TypeName = "decimal(10, 2)")]
    public decimal? PreTotalScore { get; set; }
    


    /// <summary>
    /// 一对一引用（机构）
    /// </summary>
    public virtual SysOrg SysOrg { get; set; }
    /// <summary>
    /// 一对一引用（年级）
    /// </summary>
    public virtual Grade Grade { get; set; }
    /// <summary>
    /// 一对一引用（班级）
    /// </summary>
    public virtual SchoolClass SchoolClass { get; set; }
    /// <summary>
    /// 一对一引用（校区）
    /// </summary>
    public virtual SysOrg SysOrgBranch { get; set; }
    /// <summary>
    /// 一对一引用（监测年级）
    /// </summary>
    public virtual ExamGrade ExamGrade { get; set; }

    public void Configure(EntityTypeBuilder<ExamSpecialStudent> entityBuilder, DbContext dbContext, Type dbContextLocator)
    {
        entityBuilder.HasIndex(a => new { a.ExamPlanId, a.SysOrgId }).HasDatabaseName("idx_exam_special_student_exam_plan_id_sys_org_id");
        entityBuilder.HasIndex(a => new { a.ExamPlanId, a.SysOrgId, a.SchoolClassId }).HasDatabaseName("idx_exam_special_student_exam_plan_id_soid_scid");
    }
}
