﻿using Microsoft.EntityFrameworkCore;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;

namespace YBEE.EQM.Core;

/// <summary>
/// 高中划线参照划线
/// </summary>
public class NceeBaseLine : DEntityBase
{
    /// <summary>
    /// 高考分析计划ID
    /// </summary>
    [Comment("高考分析计划ID")]
    [Required]
    public int NceePlanId { get; set; }
    /// <summary>
    /// 首选科目ID
    /// </summary>
    [Comment("首选科目ID")]
    [Required]
    public short DirectionCourseId { get; set; }
    /// <summary>
    /// 划线等级
    /// </summary>
    [Comment("划线等级")]
    [Required, Column(TypeName = "smallint")]
    public NceeLineLevel NceeLineLevel { get; set; }
    /// <summary>
    /// 比例
    /// </summary>
    [Comment("比例")]
    [Required, Column(TypeName = "decimal(10, 8)")]
    public decimal LineRate { get; set; } = 0;
    /// <summary>
    /// 原始分划线分数
    /// </summary>
    [Comment("原始分划线分数")]
    [Required, Column(TypeName = "decimal(10, 2)")]
    public decimal LineScore { get; set; } = 0;
    /// <summary>
    /// 赋分划线分数
    /// </summary>
    [Comment("赋分划线分数")]
    [Required, Column(TypeName = "decimal(10, 2)")]
    public decimal LineScoreX { get; set; } = 0;

    /// <summary>
    /// 一对一引用（高中分析计划）
    /// </summary>
    public virtual NceePlan NceePlan { get; set; }
}
