﻿using Microsoft.EntityFrameworkCore;
using System;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;

namespace YBEE.EQM.Core;

/// <summary>
/// 特殊学生
/// </summary>
[Comment("特殊学生")]
public class SpecialStudent : DEntityBase
{
    /// <summary>
    /// 机构ID
    /// </summary>
    [Comment("机构ID")]
    [Required]
    public short SysOrgId { get; set; }
    /// <summary>
    /// 校区ID
    /// </summary>
    [Comment("校区ID")]
    public short? SysOrgBranchId { get; set; }
    /// <summary>
    /// 班级ID
    /// </summary>
    [Comment("班级ID")]
    [Required]
    public long SchoolClassId { get; set; }
    /// <summary>
    /// 班级号
    /// </summary>
    [Comment("班级号")]
    [Required]
    public int ClassNumber { get; set; }
    /// <summary>
    /// 姓名
    /// </summary>
    [Comment("姓名")]
    [Required, StringLength(100)]
    public string Name { get; set; }
    /// <summary>
    /// 证件类型
    /// </summary>
    [Comment("证件类型")]
    [Required, Column(TypeName = "smallint")]
    public CertificateType CertificateType { get; set; } = CertificateType.NONE;
    /// <summary>
    /// 证件号码
    /// </summary>
    [Comment("证件号码")]
    [StringLength(50)]
    public string IdNumber { get; set; } = "";
    /// <summary>
    /// 出生日期
    /// </summary>
    [Comment("出生日期")]
    public DateTime? BirthDate { get; set; }
    /// <summary>
    /// 性别
    /// </summary>
    [Comment("性别")]
    [Required, Column(TypeName = "smallint")]
    public Gender Gender { get; set; } = Gender.UNKNOWN;
    /// <summary>
    /// 学籍号
    /// </summary>
    [Comment("学籍号")]
    [StringLength(100)]
    public string StudentNumber { get; set; } = "";
    /// <summary>
    /// 申请原因
    /// </summary>
    [Comment("申请原因")]
    [Required, StringLength(2000)]
    public string ApplyReason { get; set; }
    /// <summary>
    /// 家长姓名
    /// </summary>
    [Comment("家长姓名")]
    [StringLength(100)]
    public string PatriarchName { get; set; }
    /// <summary>
    /// 家长电话
    /// </summary>
    [Comment("家长电话")]
    [StringLength(100)]
    public string PatriarchTel {  get; set; }

    /// <summary>
    /// 认定人用户ID
    /// </summary>
    [Comment("认定人用户ID")]
    public int? IdentifiedSysUserId { get; set; }
    /// <summary>
    /// 认定时间
    /// </summary>
    [Comment("认定时间")]
    public DateTime? IdentifiedTime { get; set; }

    
    
    /// <summary>
    /// 备注
    /// </summary>
    [Comment("备注")]
    [StringLength(200)]
    public string Remark { get; set; }

    /// <summary>
    /// 一对一引用（机构）
    /// </summary>
    public virtual SysOrg SysOrg { get; set; }
    /// <summary>
    /// 一对一引用（班级）
    /// </summary>
    public virtual SchoolClass SchoolClass { get; set; }
    /// <summary>
    /// 一对一引用（校区）
    /// </summary>
    public virtual SysOrg SysOrgBranch { get; set; }
}
