﻿using Furion.FriendlyException;

namespace YBEE.EQM.Core;

/// <summary>
/// 系统错误码
/// </summary>
[ErrorCodeType]
public enum ErrorCode
{
    /// <summary>
    /// 用户名或密码不正确
    /// </summary>
    [ErrorCodeItemMetadata("用户名或密码不正确")]
    E1001,
    /// <summary>
    /// 获取账户信息失败，请重新登录
    /// </summary>
    [ErrorCodeItemMetadata("获取账户信息失败，请重新登录")]
    E1002,
    /// <summary>
    /// 账号已冻结
    /// </summary>
    [ErrorCodeItemMetadata("账户已冻结")]
    E1003,
    /// <summary>
    /// 无权限
    /// </summary>
    [ErrorCodeItemMetadata("无权限")]
    E1004,
    /// <summary>
    /// 旧密码验证失败
    /// </summary>
    [ErrorCodeItemMetadata("旧密码验证失败")]
    E1005,
    /// <summary>
    /// 密码长度应为在6至32位之间
    /// </summary>
    [ErrorCodeItemMetadata("密码长度应为在6至32位之间")]
    E1006,
    /// <summary>
    /// 未初始化
    /// </summary>
    [ErrorCodeItemMetadata("{0}未初始化", "")]
    E1007,
    /// <summary>
    /// 账户未激活
    /// </summary>
    [ErrorCodeItemMetadata("账户未激活")]
    E1008,
    /// <summary>
    /// 新密码不能与初始密码相同
    /// </summary>
    [ErrorCodeItemMetadata("新密码不能与初始密码相同")]
    E1009,
    /// <summary>
    /// 文件必须为.xls或.xlsx格式
    /// </summary>
    [ErrorCodeItemMetadata("文件必须为.xls或.xlsx格式")]
    E1010,
    /// <summary>
    /// 文件不存在
    /// </summary>
    [ErrorCodeItemMetadata("文件不存在")]
    E1011,
    /// <summary>
    /// 缺少佐证材料
    /// </summary>
    [ErrorCodeItemMetadata("{0}缺少佐证材料")]
    E1012,
    /// <summary>
    /// 自编监测号长度错误
    /// </summary>
    [ErrorCodeItemMetadata("{0}自编监测号长度错误")]
    E1013,
    /// <summary>
    /// 类型错误
    /// </summary>
    [ErrorCodeItemMetadata("{0}类型错误")]
    E1014,


    /// <summary>
    /// {0}不存在"
    /// </summary>
    [ErrorCodeItemMetadata("{0}不存在")]
    E2001,
    /// <summary>
    /// {0}已存在  默认参数：0-"记录"
    /// </summary>
    [ErrorCodeItemMetadata("{0}已存在", "记录")]
    E2002,
    /// <summary>
    /// {0}已存相同{1}  默认参数：0-""，1-"名称"
    /// </summary>
    [ErrorCodeItemMetadata("{0}中已存相同{1}", "", "名称")]
    E2003,
    /// <summary>
    /// 已存相同{0}{1}  默认参数：0-"名称"，1-""
    /// </summary>
    [ErrorCodeItemMetadata("已存相同{0}{1}", "名称", "")]
    E2004,
    /// <summary>
    /// 已存相同名称或代码
    /// </summary>
    [ErrorCodeItemMetadata("已存相同名称或代码")]
    E2005,
    /// <summary>
    /// 当前状态不能操作
    /// </summary>
    [ErrorCodeItemMetadata("{0}当前状态不能操作", "")]
    E2006,
    /// <summary>
    /// {0}未设置   默认参数：0-""
    /// </summary>
    [ErrorCodeItemMetadata("{0}未设置", "")]
    E2007,
    /// <summary>
    /// 已截止，不能上报
    /// </summary>
    [ErrorCodeItemMetadata("已截止，不能上报")]
    E2008,
    /// <summary>
    /// 该学校未在监测范围内
    /// </summary>
    [ErrorCodeItemMetadata("该学校未在监测范围内")]
    E2009,
    /// <summary>
    /// {0}已存在
    /// </summary>
    [ErrorCodeItemMetadata("{0}已存在")]
    E2010,
    /// <summary>
    /// 已存相同{0}
    /// </summary>
    [ErrorCodeItemMetadata("已存相同{0}")]
    E2011,
    /// <summary>
    /// {0}已存相同{1}
    /// </summary>
    [ErrorCodeItemMetadata("{0}中已存相同{1}")]
    E2012,
    /// <summary>
    /// 匹配错误（{0}）
    /// </summary>
    [ErrorCodeItemMetadata("匹配错误（{0}）")]
    E2013,


    /// <summary>
    /// 非法操作！禁止删除{0}  默认参数：0-""
    /// </summary>
    [ErrorCodeItemMetadata("非法操作，禁止删除{0}", "")]
    E3001,
    /// <summary>
    /// 提交失败，还有{0}个小题的题型、认知能力、预估难度、知识模块或知识点未完善。
    /// </summary>
    [ErrorCodeItemMetadata("提交失败，还有{0}个小题的题型、认知能力、预估难度、知识模块或知识点未完善。")]
    E3002,
    /// <summary>
    /// 提交失败，问题或建议未填写完整。
    /// </summary>
    [ErrorCodeItemMetadata("提交失败，问题或建议未填写完整")]
    E3003,

    /// <summary>
    /// 菜单已存在
    /// </summary>
    [ErrorCodeItemMetadata("菜单已存在")]
    E8101,
    /// <summary>
    /// 路由地址为空
    /// </summary>
    [ErrorCodeItemMetadata("路由地址为空")]
    E8102,
    /// <summary>
    /// 打开方式为空
    /// </summary>
    [ErrorCodeItemMetadata("打开方式为空")]
    E8103,
    /// <summary>
    /// 权限标识格式为空
    /// </summary>
    [ErrorCodeItemMetadata("权限标识格式为空")]
    E8104,

    /// <summary>
    /// 权限标识格式错误
    /// </summary>
    [ErrorCodeItemMetadata("权限标识格式错误")]
    E8105,
    /// <summary>
    /// 权限不存在
    /// </summary>
    [ErrorCodeItemMetadata("权限不存在")]
    E8106,
    /// <summary>
    /// 父级菜单不能为当前节点，请重新选择父级菜单
    /// </summary>
    [ErrorCodeItemMetadata("父级菜单不能为当前节点，请重新选择父级菜单")]
    E8107,

    /// <summary>
    /// 禁止删除固定角色
    /// </summary>
    [ErrorCodeItemMetadata("禁止删除固定角色")]
    E8201,
    /// <summary>
    /// 禁止修改固定角色
    /// </summary>
    [ErrorCodeItemMetadata("禁止修改固定角色")]
    E8202,


    /// <summary>
    /// 该类型不是枚举类型
    /// </summary>
    [ErrorCodeItemMetadata("该类型不是枚举类型")]
    E9001,
}